@@ -1,29 +1,15 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2014 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2014 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "krcc.h"
 #include "karchive_p.h"
 #include "loggingcategory.h"
 
-#include <QtCore/QFile>
-#include <QtCore/QDebug>
+#include <QFile>
+#include <QDebug>
 #include <QUuid>
 #include <QDateTime>
 #include <QFileInfo>
@@ -54,7 +40,7 @@ public:
     {
     }
 
-    QByteArray data() const Q_DECL_OVERRIDE
+    QByteArray data() const override
     {
         QFile f(m_resourcePath);
         if (f.open(QIODevice::ReadOnly)) {
@@ -63,7 +49,7 @@ public:
         qCWarning(KArchiveLog) << "Couldn't open" << m_resourcePath;
         return QByteArray();
     }
-    QIODevice *createDevice() const Q_DECL_OVERRIDE
+    QIODevice *createDevice() const override
     {
         return new QFile(m_resourcePath);
     }
@@ -133,8 +119,7 @@ bool KRcc::openArchive(QIODevice::OpenMode mode)
     if (!QResource::registerResource(fileName(), d->m_prefix)) {
         setErrorString(
             tr("Failed to register resource %1 under prefix %2")
-                .arg(fileName())
-                .arg(d->m_prefix));
+                .arg(fileName(), d->m_prefix));
         return false;
     }
 
@@ -145,7 +130,7 @@ bool KRcc::openArchive(QIODevice::OpenMode mode)
 
 void KRcc::KRccPrivate::createEntries(const QDir &dir, KArchiveDirectory *parentDir, KRcc *q)
 {
-    Q_FOREACH (const QString &fileName, dir.entryList()) {
+    for (const QString &fileName : dir.entryList()) {
         const QString entryPath = dir.path() + QLatin1Char('/') + fileName;
         const QFileInfo info(entryPath);
         if (info.isFile()) {
@@ -155,8 +140,9 @@ void KRcc::KRccPrivate::createEntries(const QDir &dir, KArchiveDirectory *parent
         } else {
             KArchiveDirectory *entry = new KArchiveDirectory(q, fileName, 0555, info.lastModified(),
                                                              parentDir->user(), parentDir->group(), /*symlink*/ QString());
-            parentDir->addEntry(entry);
-            createEntries(QDir(entryPath), entry, q);
+            if (parentDir->addEntryV2(entry)) {
+                createEntries(QDir(entryPath), entry, q);
+            }
         }
     }
 }
